=========
Changelog
=========

Version 0.3.3
=============
- Added option --vacations in order to export a gantt chart of the vacations per employer
- Added option --collaps_tasks in order to collaps the tasks per project to one task in order to simplify the output
- Improved some feedback at errors with missing employees

Version 0.2.4
=============
- Added --pdf option in order to convert svg file into pdf as well

Version 0.2.3
=============
- Added possibility to add margin_left and margin_right property to project to prevent cluttering of labels
- Added possibility to filter on one or more employees to only display the project of the selected employees
- Change default font size for level 0 and 1 in project plan
- Add name of employee to title if a filter was used

Version 0.1.9
=============
- In resources overview, task colors now match the colors in the project overview
- The task color can now explicitly be given. Default task color matches the project color.
- Started to update the documentation. Still needs to be finished


Version 0.1.7
=============
- Improved colouring of resources schema

Version 0.1.6
=============
- Added some basic checks on the tasks start and end dates to be more specifics on errors

Version 0.1.5
=============
- Bug today reference fixed
- Vacation now correctly added
- Font properties can be specified in setting file
- dayfist can be set to false

Version 0.1.3
=============

- Dynamic columns added
- First version of Gantt Project maker
- First bug fixes established
